#!/usr/bin/perl -w
use strict;
use ExtUtils::MakeMaker;
use File::Spec;
use CTK::Util qw/sharedstatedir sharedir/;

use constant {
        PROJECT_NAME  => "PhotoFolder",
        PROJECT_NAMEL => "photofolder",
    };

my $build_requires = {
        'CTK'                   => 2.03,
        'ExtUtils::MakeMaker'   => 6.60,
        'Test::More'            => 0.94,
    };

my $prereq_pm = {
        'CTK'                   => 2.03, # perl-CTK (libctk-perl)
        'Mojolicious'           => 7.94, # perl-Mojolicious (libmojolicious-perl)
        'Image::Magick'         => 0,
        'File::Copy'            => 0,
        'CPAN::Meta::YAML'      => 0,
    };

WriteMakefile(
    'NAME'              => PROJECT_NAME,
    'DISTNAME'          => PROJECT_NAMEL,
    'MIN_PERL_VERSION'  => 5.016001,
    'VERSION_FROM'      => 'lib/PhotoFolder.pm',
    'ABSTRACT'          => 'PhotoFolder - tool for publishing your personal folders with photos as web photo galleries',
    'BUILD_REQUIRES'    => $build_requires,
    'PREREQ_PM'         => $prereq_pm,
    'AUTHOR'            => 'Serż Minus (Sergey Lepenkov) <minus@serzik.com>',
    'LICENSE'           => 'Apache',
    'META_MERGE'        => {
        resources => {
            homepage        => 'https://www.serzik.com',
            repository      => 'https://git.mns.suffit.org/minus/photofolder.git',
            license         => 'https://www.apache.org/licenses/LICENSE-2.0.txt',
        },
    },
    macro => {
            PROJECT_NAME    => PROJECT_NAME,
            PROJECT_NAMEL   => PROJECT_NAMEL,
            PROJECT_DATADIR => '$(DESTDIR)' . File::Spec->catdir(sharedstatedir(), PROJECT_NAMEL),
            PROJECT_SHAREDIR => '$(DESTDIR)' . File::Spec->catdir(sharedir(), PROJECT_NAMEL),
        },
    clean => {
            FILES => '*.tmp',
        },
);

1;

package MY;
use CTK::Util qw/dformat/;

sub postamble {
dformat(<<'MAKE_FRAG', {TAB => "\t"});
INST_SHARE = blib$(DFSEP)share

pure_all :: configured.tmp
[TAB]$(NOECHO) $(ECHO) "Configured."

# Configure
configured.tmp : $(INST_SHARE)$(DFSEP).exists
[TAB]$(CP) -R src$(DFSEP)www$(DFSEP)* $(INST_SHARE)$(DFSEP)
[TAB]$(CP) src$(DFSEP)$(PROJECT_NAMEL).pl $(INST_SCRIPT)$(DFSEP)$(PROJECT_NAMEL).pl
[TAB]$(CP) src$(DFSEP)$(PROJECT_NAMEL).cgi $(INST_SCRIPT)$(DFSEP)$(PROJECT_NAMEL).cgi
[TAB]$(NOECHO) $(TOUCH) configured.tmp

# Create share directory
$(INST_SHARE)$(DFSEP).exists :: Makefile.PL
[TAB]$(MKPATH) $(INST_SHARE)
[TAB]$(NOECHO) $(CHMOD) $(PERM_DIR) $(INST_SHARE)
[TAB]$(NOECHO) $(TOUCH) $(INST_SHARE)$(DFSEP).exists

install :: installed.tmp
[TAB]$(NOECHO) $(ECHO) The $(PROJECT_NAME) project has been successfully installed.

installed.tmp : configured.tmp
[TAB]$(MKPATH) $(PROJECT_DATADIR)
[TAB]$(NOECHO) $(CHMOD) $(PERM_DIR) $(PROJECT_DATADIR)
[TAB]$(MKPATH) $(PROJECT_SHAREDIR)
[TAB]$(NOECHO) $(CHMOD) $(PERM_DIR) $(PROJECT_SHAREDIR)
[TAB]$(CP) -R $(INST_SHARE)$(DFSEP)* $(PROJECT_SHAREDIR)
[TAB]$(NOECHO) $(TOUCH) installed.tmp
MAKE_FRAG
}

1;

__END__
